==> haskell-polyparse-1.13.1-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 polyparse
version:              1.13.1
visibility:           public
id:                   polyparse-1.13.1-BCxmYYUJf3MBmBXo6ZXb1j
key:                  polyparse-1.13.1-BCxmYYUJf3MBmBXo6ZXb1j
license:              LicenseRef-LGPL
copyright:            (c) 2006-2016 Malcolm Wallace
maintainer:           Andreas Abel
author:               Malcolm Wallace <Malcolm.Wallace@me.com>
synopsis:             A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.

    Old homepage: <https://archives.haskell.org/projects.haskell.org/polyparse/>

category:             Text, Parsing
abi:                  b2486747d462aadd7f65ea51a90ff374
exposed:              True
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/polyparse-1.13.1
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/polyparse-1.13.1
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/polyparse-1.13.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-polyparse
hs-libraries:         HSpolyparse-1.13.1-BCxmYYUJf3MBmBXo6ZXb1j
depends:              base-4.18.3.0 bytestring-0.11.5.4 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html:         /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polyparse-1.13-13-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 polyparse
version:              1.13
visibility:           public
id:                   polyparse-1.13-LdwKes91BNc9xm9kzNQ4gM
key:                  polyparse-1.13-LdwKes91BNc9xm9kzNQ4gM
license:              LicenseRef-LGPL
copyright:            (c) 2006-2016 Malcolm Wallace
maintainer:           author
author:               Malcolm Wallace <Malcolm.Wallace@me.com>
homepage:             http://code.haskell.org/~malcolm/polyparse/
synopsis:             A variety of alternative parser combinator libraries.
description:
    This version, 1.13 is a Non-Maintainer Upload (NMU).
    Report issues to the Hackage Trustees issue tracker.

    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.

category:             Text, Parsing
abi:                  e05f1ce57e30f671e3cff2031042bd9e
exposed:              True
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text

import-dirs:          /usr/lib/ghc-9.4.8/site-local/polyparse-1.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/polyparse-1.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/polyparse-1.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-polyparse
hs-libraries:         HSpolyparse-1.13-LdwKes91BNc9xm9kzNQ4gM
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html:         /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
